| Title: | Parameters of the Experimental Designs |
|---|---|
| Description: | Here, a function has been developed to generate parameters of the input designs, as well as incidence matrices. This is a general function that can be used to investigate the characterization properties of any block design. |
| Authors: | Vinaykumar L.N. [aut, cre], Vinayaka [aut, ctb], Dalal Ashutosh [aut, ctb] |
| Maintainer: | Vinaykumar L.N. <[email protected]> |
| License: | GPL-3 |
| Version: | 0.1.0 |
| Built: | 2026-05-15 06:40:39 UTC |
| Source: | https://github.com/cran/Design.parameters |
This package includes a function for generating parameters for the input designs, as well as incidence matrices. This is a general function that can be used to investigate the characterization properties of any block design.
Parameters(input_design)Parameters(input_design)
input_design |
A design which should be in a matrix format |
Experimental designs in matrix form considering rows as blocks and fill the empty cells with zeros
library(Design.parameters) design=matrix(1:9, nrow = 3, ncol = 3) Parameters(design)library(Design.parameters) design=matrix(1:9, nrow = 3, ncol = 3) Parameters(design)