Welcome to ClientVPS Mirrors

Help for package Design.parameters
Type: Package
Title: Parameters of the Experimental Designs
Version: 0.1.0
Maintainer: Vinaykumar L.N. <vinaymandya123@gmail.com>
Description: Here, a function has been developed to generate parameters of the input designs, as well as incidence matrices. This is a general function that can be used to investigate the characterization properties of any block design.
License: GPL-3
Encoding: UTF-8
LazyData: false
NeedsCompilation: no
Packaged: 2022-10-02 07:28:08 UTC; Vinaykumar LN
Author: Vinaykumar L.N. [aut, cre], Vinayaka [aut, ctb], Dalal Ashutosh [aut, ctb]
Repository: CRAN
Date/Publication: 2022-10-03 07:40:08 UTC

Parameters of the Experimental Designs

Description

This package includes a function for generating parameters for the input designs, as well as incidence matrices. This is a general function that can be used to investigate the characterization properties of any block design.

Usage

  Parameters(input_design)

Arguments

input_design

A design which should be in a matrix format

Value

Experimental designs in matrix form considering rows as blocks and fill the empty cells with zeros

Examples

  library(Design.parameters)
  design=matrix(1:9, nrow = 3, ncol = 3)
  Parameters(design)

Need a high-speed mirror for your open-source project?
Contact our mirror admin team at info@clientvps.com.

This archive is provided as a free public service to the community.
Proudly supported by infrastructure from VPSPulse , RxServers , BuyNumber , UnitVPS , OffshoreName and secure payment technology by ArionPay.